@@ -4,6 +4,7 @@
 {-# OPTIONS_GHC -O0 #-}
 {-# OPTIONS_GHC -Wno-name-shadowing #-}
 {-# OPTIONS_GHC -Wno-type-defaults #-}
+{-# OPTIONS_GHC -fno-hpc #-}
 module Property.AdditionalProps
   ( prop_predicate_param_match_counts
   , prop_multicase_progression
@@ -19,6 +20,7 @@ import Data.List (nub)
 import Data.Proxy (Proxy(..))
 import Test.MockCat
 import Control.Monad.IO.Class (liftIO)
+import Property.Generators (resetMockHistory)
 
 perCall :: Int -> a -> a
 perCall i x = case i of
@@ -32,6 +34,7 @@ perCall i x = case i of
 -- the total recorded calls equals count of even inputs attempted.
 prop_predicate_param_match_counts :: Property
 prop_predicate_param_match_counts = forAll genVals $ \xs -> monadicIO $ do
+  run resetMockHistory
   -- build predicate mock: (Int -> Bool) returning True for all evens
   f <- run $ mock (expect even "even" ~> True)
   results <- run $ mapM (\x -> try (evaluate (f x)) :: IO (Either SomeException Bool)) xs
@@ -53,6 +56,7 @@ prop_predicate_param_match_counts = forAll genVals $ \xs -> monadicIO $ do
 -- saturate at the last value.
 prop_multicase_progression :: Property
 prop_multicase_progression = forAll genSeq $ \(arg, rs, extra) -> monadicIO $ do
+  run resetMockHistory
   f <- run $ mock $ cases [ param arg ~> r | r <- rs ]
   let totalCalls = length rs + extra
   -- NOTE [GHC9.4 duplicate-call counting]
@@ -86,6 +90,7 @@ prop_multicase_progression = forAll genSeq $ \(arg, rs, extra) -> monadicIO $ do
 -- The first run enforces a single invocation; the second expects zero for a fresh mock.
 prop_runMockT_isolation :: Property
 prop_runMockT_isolation = monadicIO $ do
+  run resetMockHistory
   -- Run 1: expect one call
   r1 <- run $ try $ runMockT $ do
     f <- liftIO $ mock (param (1 :: Int) ~> True)
@@ -112,6 +117,7 @@ prop_runMockT_isolation = monadicIO $ do
 -- list of first occurrences; reversing that list (when length >=2) fails.
 prop_partial_order_duplicates :: Property
 prop_partial_order_duplicates = forAll genDupScript $ \xs -> length xs >= 2 ==> monadicIO $ do
+  run resetMockHistory
   -- build mock over sequence
   f <- run $ mock $ cases [ param x ~> True | x <- xs ]
   run $ forM_ xs $ \x -> f x `seq` pure ()
@@ -135,7 +141,7 @@ prop_partial_order_duplicates = forAll genDupScript $ \xs -> length xs >= 2 ==>
       base <- vectorOf size (arbitrary :: Gen Int)
       -- ensure at least one duplicate by forcing first element copy if all distinct
       pure $ ensureDup base
-    ensureDup ys = if length (nub ys) == length ys && not (null ys) then head ys : ys else ys
+    ensureDup ys = if length (nub ys) == length ys && not (null ys) then (case ys of (h:_) -> h : ys; [] -> ys) else ys
     -- Check that for each earlier unique value all its indices precede all indices of later unique values.
     isClusterOrdered us seqVals = all pairOrdered pairs
       where
