@@ -1,4 +1,5 @@
 {-# LANGUAGE ScopedTypeVariables #-}
+{-# LANGUAGE TypeApplications #-}
 {-# LANGUAGE TemplateHaskell #-}
 {-# LANGUAGE DataKinds #-}
 {-# LANGUAGE FlexibleInstances #-}
@@ -6,6 +7,7 @@
 {-# LANGUAGE TypeFamilies #-}
 {-# OPTIONS_GHC -Wno-missing-export-lists #-}
 {-# OPTIONS_GHC -Wno-simplifiable-class-constraints #-}
+{-# OPTIONS_GHC -fno-hpc #-}
 module Property.ReinforcementProps
   where
 
@@ -15,6 +17,7 @@ import Control.Exception (try, SomeException, evaluate)
 import Control.Concurrent.Async (forConcurrently_)
 import UnliftIO (withRunInIO)
 import Test.MockCat hiding (any)
+import Property.Generators (resetMockHistory)
 
 --------------------------------------------------------------------------------
 -- 1. Predicate negative: failing inputs raise & are not counted
@@ -22,6 +25,7 @@ import Test.MockCat hiding (any)
 
 prop_predicate_negative_not_counted :: Property
 prop_predicate_negative_not_counted = forAll genVals $ \xs -> monadicIO $ do
+  run resetMockHistory
   f <- run $ mock (expect even "even" ~> True)
   outcomes <- run $ mapM (\x -> (try (evaluate (f x)) :: IO (Either SomeException Bool))) xs
   let evens = length (filter even xs)
@@ -53,10 +57,11 @@ makeAutoLiftMock [t|ParLazyAction|]
 
 prop_lazy_partial_force_concurrency :: Property
 prop_lazy_partial_force_concurrency = forAll genPlan $ \(arg, mask) -> monadicIO $ do
+  run resetMockHistory
   let forcedCount = length (filter id mask)
   run $ runMockT $ do
     -- expectation: arg -> arg; count only forced executions
-    _ <- _parLazy (param arg ~> arg)
+    _ <- _parLazy ((param arg ~> arg))
       `expects` do
         called (times forcedCount)
     -- prepare thunks (NOT executed yet)
@@ -81,6 +86,7 @@ prop_lazy_partial_force_concurrency = forAll genPlan $ \(arg, mask) -> monadicIO
 
 prop_partial_order_interleaved_duplicates :: Property
 prop_partial_order_interleaved_duplicates = forAll genPair $ \(a,b) -> a /= b ==> monadicIO $ do
+  run resetMockHistory
   -- Pattern a a b : [a,b] subsequence succeeds, [b,a] fails.
   f <- run $ mock $ cases [ param a ~> True
                                 , param a ~> True
