@@ -19,9 +19,14 @@ import Test.MockCat.TH.FunctionBuilderSpec as THFunctionBuilder
 import Test.MockCat.ShouldBeCalledSpec as ShouldBeCalled
 import Test.MockCat.ShouldBeCalledMockMSpec as ShouldBeCalledMockM
 import Test.MockCat.WithMockSpec as WithMock
-import Test.MockCat.ErrorDiffSpec as ErrorDiff
+import Test.MockCat.ShouldBeCalledErrorDiffSpec as ShouldBeCalledErrorDiff
+import Test.MockCat.WithMockErrorDiffSpec as WithMockErrorDiff
 import Test.MockCat.THCompareSpec as THCompare
 import ReadmeVerifySpec as ReadmeVerify
+import qualified Test.MockCat.HPCFallbackSpec as HPCFallback
+import qualified Test.MockCat.DeferredTypeErrorsSpec as DeferredTypeErrors
+import qualified Test.MockCat.MultipleMocksSpec as MultipleMocks
+import Test.MockCat.UnsafeCheck ()
 import Test.QuickCheck (property)
 import qualified Property.ConcurrentCountProp as ConcurrencyProp
 import qualified Property.LazyEvalProp as LazyEvalProp
@@ -56,8 +61,12 @@ main = hspec $ do
     ShouldBeCalled.spec
     ShouldBeCalledMockM.spec
     WithMock.spec
-    ErrorDiff.spec
+    ShouldBeCalledErrorDiff.spec
+    WithMockErrorDiff.spec
     ReadmeVerify.spec
+    HPCFallback.spec
+    DeferredTypeErrors.spec
+    MultipleMocks.spec
     describe "Property Concurrency" $ do
       it "total apply count is preserved across threads" $ property ConcurrencyProp.prop_concurrent_total_apply_count
     describe "Property Lazy Evaluation" $ do
