@@ -10,6 +10,7 @@
 {-# LANGUAGE GADTs #-}
 {-# LANGUAGE MultiParamTypeClasses #-}
 {-# LANGUAGE DuplicateRecordFields #-}
+{-# LANGUAGE TypeApplications #-}
 {-# OPTIONS_GHC -Wno-orphans #-}
 {-# OPTIONS_GHC -Wno-name-shadowing #-}
 {-# OPTIONS_GHC -Wno-unused-do-bind #-}
@@ -19,7 +20,7 @@ module Test.MockCat.TypeClassSpec (spec) where
 import Data.Text (Text)
 import Test.Hspec (Spec)
 import Test.MockCat
-import Prelude hiding (readFile, writeFile)
+import Prelude hiding (readFile, writeFile, any)
 import Data.Data
 import Data.List (find)
 import GHC.TypeLits (KnownSymbol, symbolVal)
@@ -570,6 +571,27 @@ _writeTTY p = MockT $ do
   addDefinition (Definition (Proxy :: Proxy "_writeTTY") mockInstance NoVerification)
   pure mockInstance
 
+_processPost ::
+  ( MockDispatch (IsMockSpec params) params (MockT m) (Post -> Bool)
+  , MonadIO m
+  ) =>
+  params ->
+  MockT m (Post -> Bool)
+_processPost p = MockT $ do
+  mockInstance <- unMockT $ mock (label "_processPost") p
+  ensureVerifiable mockInstance
+  addDefinition (Definition (Proxy :: Proxy "_processPost") mockInstance NoVerification)
+  pure mockInstance
+
+instance MonadIO m => UserDefinedClass (MockT m) where
+  processPost p = MockT do
+    defs <- getDefinitions
+    let
+      mockFn :: Post -> Bool
+      mockFn = fromMaybe (error "no answer found stub function `_processPost`.") $ findParam (Proxy :: Proxy "_processPost") defs
+      !result = mockFn p
+    lift $ pure result
+
 spec :: Spec
 spec = do
   -- build SpecDeps and call aggregated spec entrypoint
@@ -598,5 +620,6 @@ spec = do
         , SpecCommon.assocTypeDeps                = SpecCommon.AssocTypeDeps _produce
         , SpecCommon.concurrencyAndUnliftIODeps   = SpecCommon.ConcurrencyAndUnliftIODeps _readFile
         , SpecCommon.concurrencyDeps              = SpecCommon.ConcurrencyDeps _readFile
+        , SpecCommon.userDefinedTypeDeps          = SpecCommon.UserDefinedTypeDeps _processPost
         }
-  SpecCommon.spec deps
\ No newline at end of file
+  SpecCommon.spec deps
